@@ -3,15 +3,19 @@ import sys
 import click
 import json
 from qtpy import QtWidgets
+import yaqd_control
 
 from ._main_window import MainWindow
 from .__version__ import __version__
 
 
 @click.command()
-@click.argument("input", type=click.File("rb"))
+@click.argument("input", type=click.File("rb"), default=None, required=False)
 def main(input):
-    input = json.load(input)
+    if input is None:
+        input = json.loads(yaqd_control.list_(format="json"))
+    else:
+        input = json.load(input)
     app = QtWidgets.QApplication(sys.argv)
     window = MainWindow(input)
     window.show()
