@@ -3,10 +3,17 @@ __all__ = ["Boolean"]
 
 import time
 from functools import partial
+from typing import Dict, Tuple, Callable
 
 import qtypes
+import qtpy
+
+from ._disconnect import disconnect
+
+signals: Dict[int, Tuple[qtpy.QtCore.Signal, Callable]] = {}
 
 
+@disconnect(signals)
 def value_updated(value, item):
     item.set({"value": item.get()})
 
@@ -24,6 +31,10 @@ def Boolean(key, property, qclient):
     # make item
     item = qtypes.Bool(disabled=disabled, label=key)
     # signals and slots
-    property.updated.connect(partial(value_updated, item=item))
-    item.edited.connect(partial(set_daemon, property=property))
+    sig, func = property.updated, partial(value_updated, item=item)
+    signals[id(item)].append((sig, func))
+    sig.connect(func)
+    sig, func = item.edited, partial(set_daemon, property=property)
+    signals[id(item)].append((sig, func))
+    sig.connect(func)
     return item
