@@ -3,14 +3,23 @@ __all__ = ["Integer"]
 
 import time
 from functools import partial
+from typing import Dict, Tuple, Callable
 
 import qtypes
+import qtpy
 
 
+from ._disconnect import disconnect
+
+signals: Dict[int, Tuple[qtpy.QtCore.Signal, Callable]] = {}
+
+
+@disconnect(signals)
 def value_updated(value, item):
     item.set({"value": value})
 
 
+@disconnect(signals)
 def limits_updated(value, item):
     item.set({"minimum": value[0], "maximum": value[1]})
 
@@ -28,9 +37,15 @@ def Integer(key, property, qclient):
     # make item
     item = qtypes.Integer(disabled=disabled, label=key)
     # signals and slots
-    property.updated.connect(partial(value_updated, item=item))
+    sig, func = property.updated, partial(value_updated, item=item)
+    signals[id(item)].append((sig, func))
+    sig.connect(func)
     if hasattr(property, "limits"):
-        property.limits.finished.connect(partial(limits_updated, item=item))
+        sig, func = property.limits.finished, partial(limits_updated, item=item)
+        signals[id(item)].append((sig, func))
+        sig.connect(func)
         property.limits()
-    item.edited.connect(partial(set_daemon, property=property))
+    sig, func = item.edited, partial(set_daemon, property=property)
+    signals[id(item)].append((sig, func))
+    sig.connect(func)
     return item
