@@ -3,10 +3,18 @@ __all__ = ["String"]
 
 import time
 from functools import partial
+from typing import Dict, Tuple, Callable
 
 import qtypes
+import qtpy
 
 
+from ._disconnect import disconnect
+
+signals: Dict[int, Tuple[qtpy.QtCore.Signal, Callable]] = {}
+
+
+@disconnect(signals)
 def value_updated(value, item):
     item.set({"value": item.get()})
 
@@ -24,6 +32,10 @@ def String(key, property, qclient):
     # make item
     item = qtypes.String(disabled=disabled, label=key)
     # signals and slots
-    property.updated.connect(partial(value_updated, item=item))
-    item.edited.connect(partial(set_daemon, property=property))
+    sig, func = property.updated, partial(value_updated, item=item)
+    signals[id(item)].append((sig, func))
+    sig.connect(func)
+    sig, func = item.edited, partial(set_daemon, property=property)
+    signals[id(item)].append((sig, func))
+    sig.connect(func)
     return item
